=======
History
=======

0.1.0 (2016-03-27)
------------------

* Show code when debugging and on tracebacks
* Improve internal package and module names
* Fix line numbers (off by 1)
* Package's root namespace is no longer polluted by pinliner
* Original filename for package/modules is stored so it will be reported by
  exceptions and logging.

0.0.1 (2016-03-26)
------------------

* Basic functionality.
